@@ -32,6 +32,20 @@ GNSSLIST = {
     6: "GLONASS",
 }
 
+# Geodetic datum spheroid values:
+# WGS84, ETRS89, EPSG4326
+WGS84_SMAJ_AXIS = 6378137.0  # semi-major axis
+WGS84_FLATTENING = 298.257223563  # flattening
+# GRS80
+GRS80_SMAJ_AXIS = 6378137.0
+GRS80_FLATTENING = 298.257222101
+# OSGB36
+OSGB36_SMAJ_AXIS = 6377563.396
+OSGB36_FLATTENING = 299.3249646
+# INT1924
+INT24_SMAJ_AXIS = 6378388.0
+INT24_FLATTENING = 297.0
+
 # scaling factor constants
 SCAL9 = 1e-9  # 0.000000001
 SCAL8 = 1e-8  # 0.00000001
@@ -295,9 +309,6 @@ UBX_MSGIDS = {
     b"\x0a\x2f": "MON-SPT",
     b"\x0a\x39": "MON-SYS",
     b"\x0a\x08": "MON-TXBUF",
-    b"\x0a\x05": "MON-0a05",  # enabled by u-center debug mode but undocumented
-    b"\x0a\x11": "MON-0a11",  # as above
-    b"\x0a\x26": "MON-0a26",  # as above
     b"\x0a\x04": "MON-VER",
     # ***************************************************************
     # Navigation messages
@@ -400,7 +411,6 @@ UBX_MSGIDS = {
     # ***************************************************************
     # Security messages
     # ***************************************************************
-    b"\x27\x00": "SEC-2700",  # enabled by u-center debug mode but undocumented
     b"\x27\x09": "SEC-SIG",
     b"\x27\x10": "SEC-SIGLOG",
     b"\x27\x01": "SEC-SIGN",
@@ -503,7 +513,7 @@ UBX_MSGIDS = {
     b"\xf6\x0c": "SPARTN-1-2",  # Galileo high-precision atmosphere correction (HPAC) (Input)
     b"\xf6\x13": "SPARTN-2-0",  # Geographic area definition (GAD) (Input)
     # ***************************************************************
-    # UNKNOWN Message types (not publicly documented by u-blox)
+    # NMEA-NAV2 Message types
     # Used to poll message rates via CFG-MSG; not parsed by pyubx2
     # ***************************************************************
     b"\xf7\x00": "NMEA-NAV2-00",  #
